==> dataone.test_utilities-2.3.2-py2-none-any.whl: d1_test/mock_api/tests/test_is_authorized.py <==
# -*- coding: utf-8 -*-

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2016 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import

import responses

import d1_test.d1_test_case
import d1_test.mock_api.is_authorized as mock_is_authorized


class TestMockIsAuthorized(d1_test.d1_test_case.D1TestCase):
  @responses.activate
  def test_1000(self, mn_client_v1_v2):
    """mock_api.isAuthorized(): Returns True 'authorized_pid"""
    mock_is_authorized.add_callback(d1_test.d1_test_case.MOCK_BASE_URL)
    assert mn_client_v1_v2.isAuthorized('authorized_pid', 'read') is True

  @responses.activate
  def test_1010(self, mn_client_v1_v2):
    """mock_api.isAuthorized(): Returns False for 'unauthorized_pid"""
    mock_is_authorized.add_callback(d1_test.d1_test_case.MOCK_BASE_URL)
    assert mn_client_v1_v2.isAuthorized('unauthorized_pid', 'read') is False

==> dataone.test_utilities-3.0.3-py2-none-any.whl: d1_test/mock_api/tests/test_is_authorized.py <==
# -*- coding: utf-8 -*-

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2016 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import responses

import d1_test.d1_test_case
import d1_test.mock_api.is_authorized as mock_is_authorized


class TestMockIsAuthorized(d1_test.d1_test_case.D1TestCase):
  @responses.activate
  def test_1000(self, mn_client_v1_v2):
    """mock_api.isAuthorized(): Returns True for authorized_pid"""
    mock_is_authorized.add_callback(d1_test.d1_test_case.MOCK_MN_BASE_URL)
    assert mn_client_v1_v2.isAuthorized('authorized_pid', 'read') is True

  @responses.activate
  def test_1010(self, mn_client_v1_v2):
    """mock_api.isAuthorized(): Returns False for unauthorized_pid"""
    mock_is_authorized.add_callback(d1_test.d1_test_case.MOCK_MN_BASE_URL)
    assert mn_client_v1_v2.isAuthorized('unauthorized_pid', 'read') is False
